@@ -21,18 +21,16 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/examples/scribble.pl,v 1.9 2003/11/08 00:15:32 pcg Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/examples/scribble.pl,v 1.10 2004/01/25 06:52:01 muppetman Exp $
 #
 
 # this was originally gtk-2.2.0/examples/scribble-simple/scribble-simple.c
 # ported to gtk2-perl by muppet
 
 use strict;
+use Glib qw/TRUE FALSE/;
 use Gtk2;
 
-use constant TRUE => 1;
-use constant FALSE => 0;
-
 # Backing pixmap for drawing area
 my $pixmap = undef;
 
