@@ -18,19 +18,15 @@
 # Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 # Boston, MA 02111-1307, USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/examples/socket.pl,v 1.6 2003/09/22 00:04:23 rwmcfa1 Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/examples/socket.pl,v 1.7 2004/01/25 06:52:01 muppetman Exp $
 #
 
 # this was originally gtk-2.2.1/examples/buttonbox/buttonbox.c
 # ported to gtk2-perl by rm
 
 use strict;
-use Gtk2;
-
-use constant TRUE => 1;
-use constant FALSE => 0;
-
-Gtk2->init;
+use Glib qw/TRUE FALSE/;
+use Gtk2 -init;
 
 my $pid;
 my $socket;
