@@ -17,9 +17,7 @@
 
 package drawingarea;
 
-use constant FALSE => 0;
-use constant TRUE => 1;
-
+use Glib qw(TRUE FALSE);
 use Gtk2;
 
 
