@@ -1,5 +1,5 @@
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/pm/SimpleList.pm,v 1.21.2.4 2004/04/11 23:19:22 kaffeetisch Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/pm/SimpleList.pm,v 1.21.2.5 2004/04/19 18:12:27 kaffeetisch Exp $
 #
 
 #########################
@@ -537,7 +537,19 @@ arbitrary new column types before calling the new function.
 
 =over
 
-=item $slist = Gtk2::SimpleList->new (cname, ctype, [cname, ctype, ...])
+=item $slist = Gtk2::SimpleList->new ($cname, $ctype, ...)
+
+=over
+
+=over
+
+=item * $cname (string)
+
+=item * $ctype (string)
+
+=back
+
+=back
 
 Creates a new Gtk2::SimpleList object with the specified columns. The parameter
 C<cname> is the name of the column, what will be displayed in the list headers if
@@ -555,7 +567,21 @@ or the name of a custom type you add with C<add_column_type>.
 These should be provided in pairs according to the desired columns for your
 list.
 
-=item $slist = Gtk2::SimpleList->new_from_treeview (treeview, cname, ctype, ...)
+=item $slist = Gtk2::SimpleList->new_from_treeview ($treeview, $cname, $ctype, ...)
+
+=over
+
+=over
+
+=item * $treeview (Gtk2::TreeView)
+
+=item * $cname (string)
+
+=item * $ctype (string)
+
+=back
+
+=back
 
 Like C<< Gtk2::SimpleList->new() >>, but turns an existing Gtk2::TreeView into
 a Gtk2::SimpleList.  This is intended mostly for use with stuff like Glade,
@@ -563,9 +589,19 @@ where the widget is created for you.  This will create and attach a new model
 and remove any existing columns from I<treeview>.  Returns I<treeview>,
 re-blessed as a Gtk2::SimpleList.
 
-=item $slist->set_data_array (arrayref)
+=item $slist->set_data_array ($arrayref)
 
-Set the data in the list to the array reference arrayref. This is completely
+=over
+
+=over
+
+=item * $arrayref (array reference)
+
+=back
+
+=back
+
+Set the data in the list to the array reference $arrayref. This is completely
 equivalent to @{$list->{data}} = @{$arrayref} and is only here for convenience
 and for those programmers who don't like to type-cast and have static, set once
 data.
@@ -574,9 +610,19 @@ data.
 
 Return the indices of the selected rows in the ListStore.
 
-=item $slist->select (index, ...);
+=item $slist->select ($index, ...);
 
-=item $slist->unselect (index, ...);
+=item $slist->unselect ($index, ...);
+
+=over
+
+=over
+
+=item * $index (integer)
+
+=back
+
+=back
 
 Select or unselect rows in the list by index.  If the list is set for multiple
 selection, all indices in the list will be set/unset; otherwise, just the
@@ -586,9 +632,31 @@ To set the selection mode, or to select all or none of the rows, use the normal
 TreeView/TreeSelection stuff, e.g.  $slist->get_selection and the TreeSelection
 methods C<get_mode>, C<set_mode>, C<select_all>, and C<unselect_all>.
 
-=item $slist->set_column_editable (index, editable)
+=item $slist->set_column_editable ($index, $editable)
 
-=item boolean = $slist->get_column_editable (index)
+=over
+
+=over
+
+=item * $index (integer)
+
+=item * $editable (boolean)
+
+=back
+
+=back
+
+=item boolean = $slist->get_column_editable ($index)
+
+=over
+
+=over
+
+=item * $index (integer)
+
+=back
+
+=back
 
 This is a very simple interface to Gtk2::TreeView's editable text column cells.
 All columns which use the attr "text" (basically, any text or number column,
@@ -598,7 +666,18 @@ in-place editing.
 
 C<get_column_editable> tells you if column I<index> is currently editable.
 
-=item Gtk2::SimpleList->add_column_type (type_name, ...)
+=item Gtk2::SimpleList->add_column_type ($type_name, ...)
+
+
+=over
+
+=over
+
+=item $type_name (string)
+
+=back
+
+=back
 
 Add a new column type to the list of possible types. Initially six column types
 are defined, text, int, double, bool, scalar, and pixbuf. The bool column type
